==> alg-model-99.0.35-20210526.085257-1-sources.jar: cn/com/duiba/nezha/alg/model/vo/ParamsDo.java <==
package cn.com.duiba.nezha.alg.model.vo;

import java.io.Serializable;
import java.util.Map;

public class ParamsDo implements Serializable {
    //    private static final long serialVersionUID = -316102112618444133L;
    private Integer dim;
    private Integer factorNum;

    private Double correct;
    private Double weight0;
    private Map<Integer, Double> weight;

    private Map<String, Integer> codeMap;

    /**新增
     *
     * @return
     */
    private Map<Integer, Map<Integer, Double>> vector;

    private Map<String, Map<Integer, Double>> vectorC; // FwFM中的域交叉权重

    private Map<String,Map<Integer, Map<Integer, Double>>> vectorV3;


    public void setDim(Integer dim) {
        this.dim = dim;
    }

    public Integer getDim() {
        return this.dim;
    }

    public Double getCorrect() {
        return correct;
    }

    public void setCorrect(Double correct) {
        this.correct = correct;
    }

    public void setFactorNum(Integer factorNum) {
        this.factorNum = factorNum;
    }

    public Integer getFactorNum() {
        return this.factorNum;
    }

    public void setWeight0(Double weight0) {
        this.weight0 = weight0;
    }

    public Double getWeight0() {
        return this.weight0;
    }

    public void setWeight(Map<Integer, Double> weight) {
        this.weight = weight;
    }

    public Map<Integer, Double> getWeight() {
        return this.weight;
    }

    public void setVector(Map<Integer, Map<Integer, Double>> vector) {
        this.vector = vector;
    }

    public Map<Integer, Map<Integer, Double>> getVector() {
        return this.vector;
    }



    public Map<String, Map<Integer, Map<Integer, Double>>> getVectorV3() {
        return vectorV3;
    }

    public void setVectorV3(Map<String, Map<Integer, Map<Integer, Double>>> vectorV3) {
        this.vectorV3 = vectorV3;
    }

    public Map<String, Map<Integer, Double>> getVectorC() {
        return vectorC;
    }

    public void setVectorC(Map<String, Map<Integer, Double>> vectorC) {
        this.vectorC = vectorC;
    }
}

==> alg-model-99.0.36-20210526.113752-1-sources.jar: cn/com/duiba/nezha/alg/model/vo/ParamsDo.java <==
package cn.com.duiba.nezha.alg.model.vo;

import java.io.Serializable;
import java.util.Map;

public class ParamsDo implements Serializable {
    //    private static final long serialVersionUID = -316102112618444133L;
    private Integer dim;
    private Integer factorNum;

    private Double correct;
    private Double weight0;
    private Map<Integer, Double> weight;

    private Map<String, Integer> codeMap;

    /**新增
     *
     * @return
     */
    private Map<Integer, Map<Integer, Double>> vector;

    private Map<String, Map<String, Double>> vectorC; // FwFM中的域交叉权重

    private Map<String,Map<Integer, Map<Integer, Double>>> vectorV3;


    public void setDim(Integer dim) {
        this.dim = dim;
    }

    public Integer getDim() {
        return this.dim;
    }

    public Double getCorrect() {
        return correct;
    }

    public void setCorrect(Double correct) {
        this.correct = correct;
    }

    public void setFactorNum(Integer factorNum) {
        this.factorNum = factorNum;
    }

    public Integer getFactorNum() {
        return this.factorNum;
    }

    public void setWeight0(Double weight0) {
        this.weight0 = weight0;
    }

    public Double getWeight0() {
        return this.weight0;
    }

    public void setWeight(Map<Integer, Double> weight) {
        this.weight = weight;
    }

    public Map<Integer, Double> getWeight() {
        return this.weight;
    }

    public void setVector(Map<Integer, Map<Integer, Double>> vector) {
        this.vector = vector;
    }

    public Map<Integer, Map<Integer, Double>> getVector() {
        return this.vector;
    }



    public Map<String, Map<Integer, Map<Integer, Double>>> getVectorV3() {
        return vectorV3;
    }

    public void setVectorV3(Map<String, Map<Integer, Map<Integer, Double>>> vectorV3) {
        this.vectorV3 = vectorV3;
    }

    public Map<String, Map<String, Double>> getVectorC() {
        return vectorC;
    }

    public void setVectorC(Map<String, Map<String, Double>> vectorC) {
        this.vectorC = vectorC;
    }
}
